###################
Lexor Documentation
###################

A document converter implemented in Python.

Basic Usage
===========

.. toctree::
   :maxdepth: 1

    What is lexor? <lexor>
    Installation <installation>
    Getting Started <start>

Command Line
============

.. toctree::
   :maxdepth: 2

    Commands <commands/index>


Topics
======

.. toctree::
  :maxdepth: 2
  
  Topics <topics/index>


Lexor API
=========

.. toctree::
   :maxdepth: 2

    API <api/index>

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

-------

This version of the documentation was built |today|.
